@@ -6,7 +6,7 @@ use Moose;
 use lib 'lib';
 use lib 'data_seed';
 use Nice::Try;
-use aliased 'Javonet::Core::Handler::Exception' => 'Exception';
+use aliased 'Javonet::Core::Exception::Exception' => 'Exception';
 extends 'Javonet::Core::Handler::CommandHandler::AbstractCommandHandler';
 
 sub new {
@@ -34,7 +34,7 @@ sub process {
         return 0;
     }
     catch ( $e ) {
-        return $e;
+        return Exception->new($e);
     }
 }
 
